# KomaruScriptV2 [ Beta Full ]

Свой собственный мощный язык программирования, который работает как Python, но лучше и содержит всё нужное из коробки! 
Он устанавливает все ваши самые нужные популярные библиотеки (Flask, Pygame, PyAutoGUI, pyTelegramBotAPI, sherlock и другие) автоматически.

Плюс ко всему — ваша личная крутая иконка "Комару" для всех ваших файлов `.ks` на ОС Windows.

## Установка
```bash
pip install komaruscript
```

## Как пользоваться
После установки откройте консоль и введите главную команду:

```bash
komaru menu
```

Появится красивое меню, где вы можете:
1. Запускать свои скрипты `.ks`.
2. Сразу компилировать скрипты в готовый файл `.exe`. 
3. Скачивать дополнительные библиотеки (pip).
4. Создавать шаблоны файлов нового проекта.
5. Запускать красивую информацию о системе с ASCII-маскотом.
6. Выполнить автоматическую регистрацию иконки для `.ks` файлов на Windows.

## Авторы и контакты
- **Email:** komaru.trende@gmail.com
- **Telegram Author:** @KomaruEat
- **Telegram Channel:** @KomaruCharge
